@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: app.c,v 1.20 2003/11/24 21:14:16 dom Exp $
- *   $Date: 2003/11/24 21:14:16 $
+ *   $Id: app.c,v 1.23 2003/11/24 22:10:40 dom Exp $
+ *   $Date: 2003/11/24 22:10:40 $
  *
  *
  *   Implements the application
@@ -133,7 +133,7 @@ void delete_app(app_t *app)
 
 static int app_main(menu_t *menu,app_t *app, int sel)
 {   
-    app->menu = new_menu(app->render,NULL,app,app->gui,MENU_NUMBERS);
+    app->menu = new_menu(app->dongle,app->render,NULL,app,MENU_NUMBERS);
     menu_set_title(app->menu,"MediaMVP");
     menu_add(app->menu,"Live TV",app_live_tv);
     menu_add(app->menu,"Live Radio",app_live_radio);
@@ -160,7 +160,7 @@ static int app_live_tv(menu_t *menu,app_t *app, int sel)
     /* Force a re-read of the channel file */
     read_channel_file(c_livetv_file,&livetv_num,&livetv,&livetv_time);
 
-    child = new_menu(app->render,menu,app,app->gui,0);
+    child = new_menu(app->dongle,app->render,menu,app,0);
     menu_set_title(child,"Live TV"); 
 
     for ( i = 0; i < livetv_num; i++ ) {
@@ -266,7 +266,7 @@ static int app_live_radio(menu_t *menu,app_t *app, int sel)
 
     /* Force a re-read of the channel file */
     read_channel_file(c_liveradio_file,&liveradio_num,&liveradio,&liveradio_time);
-    child = new_menu(app->render,menu,app,app->gui,0);
+    child = new_menu(app->dongle,app->render,menu,app,0);
     menu_set_title(child,"Live Radio Stations");  
     for ( i = 0; i < liveradio_num; i++ ) {
         chan = &liveradio[i];
@@ -358,7 +358,7 @@ static int liveradio_ack(int acktype, void *param, unsigned char *buf, int len)
 static int app_recordings(menu_t *menu,app_t *app, int sel)
 {
     menu_t   *child;
-    child = new_menu(app->render,menu,app,app->gui,0);
+    child = new_menu(app->dongle,app->render,menu,app,0);
     menu_set_title(child,"Video Recordings");  
 
 
@@ -369,7 +369,7 @@ static int app_recordings(menu_t *menu,app_t *app, int sel)
 static int app_music(menu_t *menu,app_t *app, int sel)
 {
     menu_t   *child;
-    child = new_menu(app->render,menu,app,app->gui,0);
+    child = new_menu(app->dongle,app->render,menu,app,0);
     menu_set_title(child,"Music");   
     menu_display(child);
     return 1;
@@ -387,9 +387,9 @@ static int app_settings(menu_t *menu,app_t *app, int sel)
     static char     *tvmode[]  = { "NTSC", "PAL" };
     static char     *flicker[] = { "None", "Low", "Medium", "High" };
     static char     *output[]  = { "RGB Detected", "Svideo", "Composite", "RGB/Composite" };
-    static char     *aspect[]  = { "16:9", "4:3" };
+    static char     *aspect[]  = { "4:3", "16:9" };
 
-    child = new_menu(app->render,menu,app,app->gui,0);
+    child = new_menu(app->dongle,app->render,menu,app,0);
     menu_set_title(child,"Settings");
 
  
@@ -453,7 +453,7 @@ static int process_settings(menu_t *menu,app_t *app, int sel)
 	gui_send_settings(app->gui,RDC_SETTINGS_SAVE);
 	return 0;
     default:
-	return 1;   /* Carry on displaying */
+	return 0;   /* Carry on displaying */
     } 
 }
 
