@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: gui.c,v 1.22 2003/11/24 20:34:37 dom Exp $
- *   $Date: 2003/11/24 20:34:37 $
+ *   $Id: gui.c,v 1.23 2003/11/24 21:52:00 dom Exp $
+ *   $Date: 2003/11/24 21:52:00 $
  *
  *
  *   Handles the GUI...
@@ -102,6 +102,8 @@ gui_t *new_gui(dongle_t *dongle)
     gui_t  *gui;
 
     gui = malloc(sizeof(*gui));
+    dongle->gui = gui;
+
     gui->dongle = dongle;
     gui->state  = VNC_VERSION;
     gui->render = new_render(c_width,c_depth);
@@ -140,7 +142,7 @@ static void gui_accept(int fd, short event, void *arg)
     printf("Accept GUI\n");
     dongle = dongle_return(hostname);
 
-    dongle->gui = gui = new_gui(dongle);
+    gui = new_gui(dongle);
 
     gui->fd = cfd;
 
