@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: keys.c,v 1.6 2003/11/19 16:25:53 dom Exp $
- *   $Date: 2003/11/19 16:25:53 $
+ *   $Id: keys.c,v 1.7 2003/11/24 20:18:40 dom Exp $
+ *   $Date: 2003/11/24 20:18:40 $
  *
  *
  *   Handle keys
@@ -33,8 +33,8 @@ static mvpkey_t defkeys[] = {
     { 0x0d, "OK", kOk },
     { 0x0e, "Rewind", kFastRew },
     { 0x0f, "Forward", kFastFwd },
-    { 0x10, "Vol-", kVolUp },
-    { 0x11, "Vol+", kVolDn },
+    { 0x10, "Vol+", kVolUp },
+    { 0x11, "Vol-", kVolDn },
     { 0x12, "Ch+", kChanUp },
     { 0x13, "Ch-", kChanDn },
     { 0x14, "Power", kPower },
