@@ -3,8 +3,8 @@
  *
  *   (C) 2003 Dominic Morris
  *
- *   $Id: udp.c,v 1.11 2003/11/24 00:30:27 dom Exp $
- *   $Date: 2003/11/24 00:30:27 $
+ *   $Id: udp.c,v 1.12 2003/11/24 22:24:57 dom Exp $
+ *   $Date: 2003/11/24 22:24:57 $
  *
  *
  *   Handles the initial UDP phase
@@ -76,9 +76,11 @@ static void          parse_udp(udpprot_t *prot,unsigned char *buf, int len);
 static void          serialise_udp(udpprot_t *prot, unsigned char *buf, int len);
 
 static int           c_udpport      = 16881;
+static char          c_olddongle    = FALSE;
 
 void udp_config()
 {
+    iniparse_add("main:olddongle",OPT_BOOL,&c_olddongle);
     iniparse_add("udp:port",OPT_INT,&c_udpport);
 }
 
@@ -136,7 +138,11 @@ static void udp_read(int fd, short event, void *arg)
 
         /* FIXME Here to support multiple clients */
         prot.guiserv_addr = ntohl(c_gui_hostip);
-        prot.guiserv_port = c_gui_port - 100;
+	if ( c_olddongle ) {
+	    prot.guiserv_port = c_gui_port - 100;
+	} else {
+	    prot.guiserv_port = c_gui_port;
+	}
         prot.conserv_addr = ntohl(c_stream_hostip);
         prot.conserv_port = c_stream_port;
         prot.serv_addr = ntohl(main_interfaceip);  /* No idea what this is.. */
